16.13. cdist-type__block(7) — cdist 6.9.8 documentation

# 16.13. cdist-type__block(7)

## 16.13.1. NAME

cdist-type__block - Manage blocks of text in files

## 16.13.2. DESCRIPTION

Manage a block of text in an existing file. The block is identified using the prefix and suffix parameters. Everything between prefix and suffix is considered to be a managed block of text.

## 16.13.3. REQUIRED PARAMETERS

text

  the text to manage. If text is '-' (dash), take what was written to stdin as the text.

## 16.13.4. OPTIONAL PARAMETERS

file

  the file in which to manage the text block. Defaults to object_id.

prefix

  the prefix to add before the text. Defaults to #cdist:__block/$__object_id

suffix

  the suffix to add after the text. Defaults to #/cdist:__block/$__object_id

state

  'present' or 'absent', defaults to 'present'

## 16.13.5. MESSAGES

add

  block was added

update

  block was updated/changed

remove

  block was removed

## 16.13.6. EXAMPLES

    # text from argument
    __block /path/to/file \
       --prefix '#start' \
       --suffix '#end' \
       --text 'some\nblock of\ntext'

    # text from stdin
    __block some-id \
       --file /path/to/file \
       --text - << DONE
    here some block
    of text
    DONE

## 16.13.7. AUTHORS

Steven Armstrong <steven-cdist--@--armstrong.cc>

## 16.13.8. COPYING

Copyright (C) 2013 Steven Armstrong. You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.